@@ -1,5 +1,6 @@
 # shadowstep/element/base.py
 
+import re
 import inspect
 import logging
 logger = logging.getLogger(__name__)
@@ -27,18 +28,20 @@ class ElementBase:
     def __init__(self,
                  locator: Union[Tuple, Dict[str, str], str, WebElement] = None,
                  base=None,
-                 timeout: int = 30,
+                 timeout: float = 30,
                  poll_frequency: float = 0.5,
                  ignored_exceptions: typing.Optional[WaitExcTypes] = None,
-                 contains: bool = False):
+                 contains: bool = False,
+                 native: WebElement = None):
         self.logger = logger
         self.driver: WebDriver = None
         self.locator: Union[Tuple, Dict[str, str], 'Element'] = locator
         self.base = base  # Shadowstep instance
-        self.timeout: int = timeout
+        self.timeout: float = timeout
         self.poll_frequency: float = poll_frequency
         self.ignored_exceptions: typing.Optional[WaitExcTypes] = ignored_exceptions
         self.contains: bool = contains
+        self.native: WebElement = native
         self.id = None
         self.locator_converter = LocatorConverter()
 
@@ -99,8 +102,13 @@ class ElementBase:
                        contains: bool = False) -> Optional[Tuple[str, str]]:
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         if isinstance(locator, tuple):
-            return locator
+            by, value = locator
+            # Удаляем части типа [@attr='null']
+            value = re.sub(r"\[@[\w\-]+='null'\]", "", value)
+            return by, value
         elif isinstance(locator, dict):
+            # Удаляем ключи, у которых значение == 'null'
+            locator = {k: v for k, v in locator.items() if v != 'null'}
             locator = self.handle_dict_locator(locator, contains)
         return locator
 
